@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 11770 2019-11-01 05:29:22Z Andy $
+# $Id: __init__.py 11771 2019-11-01 08:29:32Z Andy $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Andy $ (last)
-# $Date: 2019-11-01 13:29:22 +0800 (週五, 01 十一月 2019) $
-# $Revision: 11770 $
+# $Date: 2019-11-01 16:29:32 +0800 (週五, 01 十一月 2019) $
+# $Revision: 11771 $
 
 from __future__ import print_function
 
@@ -308,9 +308,10 @@ def attachSettings(settingsDict, warns=True, printDetail=True):
         ALLOWED_HOSTS += settingsDict['ALLOWED_DOMAINS']
     else:
         if settingsDict['SERVER_MODE'] != DEVELOPMENT:
-            if warns:
-                warnWithout(
-                    'ALLOWED_DOMAINS', settingsDict, defaultAllowedDomains)
+            if not settingsDict.get('IUNO_SITE_DOMAIN_NAMES', None):
+                if warns:
+                    warnWithout(
+                        'ALLOWED_DOMAINS', settingsDict, defaultAllowedDomains)
 
     adminDefaults = {
         'ADMINS': ADMINS,
@@ -795,7 +796,6 @@ def attachSettings(settingsDict, warns=True, printDetail=True):
     #=========================================================================
     
     #=========================================================================
-    #ANDY
     # Iuno.deploy.   
     try:
         checkImportPackage('Iuno.deploy', settingsDict)
@@ -804,10 +804,10 @@ def attachSettings(settingsDict, warns=True, printDetail=True):
     else:
         import Iuno.deploy
     
-    require('IUNO_SITE_DOMAIN_NAMES', settingsDict)
+    if settingsDict['SERVER_MODE'] != DEVELOPMENT:
+        require('IUNO_SITE_DOMAIN_NAMES', settingsDict)
     allowedHosts = Iuno.deploy.attachSettings(settingsDict, 
-        settingsDict['IUNO_SITE_DOMAIN_NAMES'])   #沒設要required
-    # update(settingsDict, {ALLOWED_HOSTS: allowedHosts})
+        settingsDict.get('IUNO_SITE_DOMAIN_NAMES', None))
     #=========================================================================
  
     #=========================================================================
